/*
 * Copyright (C)2005-2019 Haxe Foundation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package python.internal;

@:ifFeature("has_enum", "Enum.*")
@:native("Enum")
class EnumImpl {
	@:ifFeature("has_enum", "Enum.*")
	public var tag:String;

	@:ifFeature("has_enum", "Enum.*")
	public var index:Int;

	@:ifFeature("has_enum", "Enum.*")
	public var params:Tuple<Dynamic>;

	@:ifFeature("has_enum", "Enum.*")
	public function new(tag, index, params) {
		this.tag = tag;
		this.index = index;
		this.params = params;
	}

	@:ifFeature("has_enum", "Enum.*")
	function __str__() {
		return if (params == null) {
			tag;
		} else {
			python.Syntax.code("{0} + '(' + (', '.join(str(v) for v in {1})) + ')'", tag, params);
		}
	}
}
